slepc-3.18.0 2022-10-01
Report Typos and Errors

# PEPCISSGetRefinement

Gets the values of various refinement parameters in the CISS solver.

### Synopsis

    #include "slepcpep.h"
    PetscErrorCode PEPCISSGetRefinement(PEP pep, PetscInt *inner, PetscInt *blsize)

Not Collective

### Input Parameter

| pep | - the polynomial eigensolver context

### Output Parameters

| inner | - number of iterative refinement iterations (inner loop)
| blsize | - number of iterative refinement iterations (blocksize loop)

### See Also

PEPCISSSetRefinement()

### Level

advanced

### Location

src/pep/impls/ciss/pciss.c
Index of all PEP routines
Table of Contents for all manual pages
Index of all manual pages